Module tests

Module tests 

Modules

accept_bi_stream
closed_bi_read_stream
closed_bi_send_stream
closed_uni_stream
datagrams
datagrams_read_into
read_resize_buf
read_small_buf
session_drop
This test ensures that when the session is dropped we get the expected effect - which is that the streams, their readers and writers and the datagrams readers and writers are closed.
streams
tokio_io
tokio_io_read_buf_resize
tokio_io_read_small_buf